@@ -8,8 +8,8 @@
     n <- attr(m1, "Size")
     if (n != attr(m2, "Size")) 
         stop("Non convenient dimension")
-    m1 <- dist2mat(m1)
-    m2 <- dist2mat(m2)
+    m1 <- as.matrix(m1)
+    m2 <- as.matrix(m2)
     col <- ncol(m1)
     res <- .C("testdistRV", as.integer(nrepet), as.integer (n), as.double(m1),
         as.double(m2), RV=double(nrepet+1),PACKAGE="ade4")$RV
